package org.foxarmy.barcodescannerforemployees.activities

import android.content.Intent
import android.os.Bundle
import android.widget.ArrayAdapter
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import org.foxarmy.barcodescannerforemployees.Net
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.databinding.ActivityLoginBinding
import org.foxarmy.barcodescannerforemployees.noInternetConnectionAvailableNotification
import org.foxarmy.barcodescannerforemployees.parseIntArray
import org.json.JSONObject

class LoginActivity : AppCompatActivity() {

    private lateinit var binding: ActivityLoginBinding;

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityLoginBinding.inflate(layoutInflater);
        setContentView(binding.root)

        fillUpLanguagesSpinner()

        val sharedPreferences = org.foxarmy.barcodescannerforemployees.getPreferences(this)

        binding.loginButton.setOnClickListener {
            val server = binding.serverTextEdit.text.toString()
            val username = binding.usernameTextEdit.text.toString()
            val password = binding.passwordTextEdit.text.toString()
            val language = resources.getStringArray(R.array.languages)[binding.languageSpinner.selectedItemPosition]
            sharedPreferences.edit().putString("language", language).apply()

            val net = Net()
            net.language = sharedPreferences.getString("language", "en-US")!!
            net.server = server

            if (!net.serverIsAvailable(this)) {
                noInternetConnectionAvailableNotification(this)
            } else {
                val response = net.login(username, password)
                val responseText = response.body!!.string()
                if (response.code != 200) {
                    Toast.makeText(this, responseText, Toast.LENGTH_SHORT).show()
                } else {
                    val json = JSONObject(responseText)
                    sharedPreferences.edit().putString("token", json["token"].toString()).apply()
                    net.token = json["token"].toString()
                    sharedPreferences.edit().putInt("userId", json["id"].toString().toInt()).apply()
                    sharedPreferences.edit().putString("server", server).apply()


                    val r = net.getMyGroups().body!!.string()
                    if (r == "" || r == "[]") {
                        val intent = Intent(this, GroupActivity::class.java)
                        startActivity(intent)
                        finish()
                    }
                    val myGroups = parseIntArray(r).map { a -> a.toString()}

                    sharedPreferences.edit().putStringSet("groups", myGroups.toSet()).apply()
                    sharedPreferences.edit().putString("currentGroup", myGroups[0]).apply()

                    val intent = Intent(this, MainActivity::class.java)
                    startActivity(intent)
                    finish()
                }
            }
        }

        binding.registerButton.setOnClickListener {
            val server = binding.serverTextEdit.text.toString()
            val username = binding.usernameTextEdit.text.toString()
            val password = binding.passwordTextEdit.text.toString()
            val language = resources.getStringArray(R.array.languages)[binding.languageSpinner.selectedItemPosition]
            sharedPreferences.edit().putString("language", language).apply()
            sharedPreferences.edit().putString("server", server).apply()

            val net = Net()
            net.language = language
            net.server = server

            if (!net.serverIsAvailable(this)) {
                noInternetConnectionAvailableNotification(this)
            } else {
                val response = net.registerAccount(username, password);
                val responseText = response.body!!.string()
                if (response.code != 200) {
                    Toast.makeText(this, responseText, Toast.LENGTH_SHORT).show();
                } else {
                    sharedPreferences.edit().putInt("userId", responseText.toInt()).apply()
                    val token = JSONObject(net.login(username, password).body!!.string())["token"].toString()
                    sharedPreferences.edit().putString("token", token).apply()

                    sharedPreferences.edit().putString("server", server).apply()
                    val intent = Intent(this, GroupActivity::class.java)
                    startActivity(intent)
                    finish()
                }
            }
        }

        binding.offlineButton.setOnClickListener {
            sharedPreferences.edit().putString("currentGroup", "offline").apply()
            sharedPreferences.edit().putStringSet("groups", setOf("offline")).apply()

            val intent = Intent(this, MainActivity::class.java)
            startActivity(intent)
            finish()
        }
    }

    private fun fillUpLanguagesSpinner() {
        val languages = resources.getStringArray(R.array.languages)
        val arrayAdapter = ArrayAdapter(this, androidx.appcompat.R.layout.support_simple_spinner_dropdown_item, languages)
        arrayAdapter.setDropDownViewResource(androidx.appcompat.R.layout.support_simple_spinner_dropdown_item)
        binding.languageSpinner.adapter = arrayAdapter
    }

}