package org.foxarmy.barcodescannerforemployees.activities

import android.content.Context
import android.content.Intent
import android.content.SharedPreferences
import android.os.Bundle
import android.view.View
import android.widget.EditText
import android.widget.PopupMenu
import android.widget.Toast
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import okhttp3.Response
import org.foxarmy.barcodescannerforemployees.Net
import org.foxarmy.barcodescannerforemployees.R
import org.foxarmy.barcodescannerforemployees.databinding.ActivityManageGroupBinding
import org.foxarmy.barcodescannerforemployees.parseIntArray
import org.foxarmy.barcodescannerforemployees.views.GroupMemberView

class ManageGroupActivity : AppCompatActivity(){
    private lateinit var binding: ActivityManageGroupBinding
    private var isAdmin: Boolean = false
    private lateinit var sharedPreferences: SharedPreferences
    private lateinit var net: Net
    private var groupId: Int = 0

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        binding = ActivityManageGroupBinding.inflate(layoutInflater)
        setContentView(binding.root)

        groupId = intent.extras!!.getInt("groupId")

        sharedPreferences = org.foxarmy.barcodescannerforemployees.getPreferences(this)

        net = Net()

        net.token = sharedPreferences.getString("token", "")!!
        net.server = sharedPreferences.getString("server", "")!!
        net.language = sharedPreferences.getString("language", "en-US")!!


        setUpMembers()

        binding.renameButton.setOnClickListener {
            val input = EditText(this)
            AlertDialog.Builder(this)
                .setTitle(getString(R.string.new_group_name))
                .setView(input)
                .setPositiveButton(getString(R.string.ok)) { _, _, ->
                    val newName = input.text.toString()
                    val response = net.renameGroup(groupId, newName)
                    Toast.makeText(this, response.body!!.string(), Toast.LENGTH_LONG).show()
                }
                .setNegativeButton(getString(R.string.cancel)) {_, _, ->

                }.show()
        }

        binding.leaveButton.setOnClickListener {
            val response: Response = net.leaveGroup(groupId)
            Toast.makeText(this, response.body!!.string(), Toast.LENGTH_SHORT).show()
            if (response.code == 200) {
                val groups = sharedPreferences.getStringSet("groups", emptySet())!!
                groups.remove(groupId.toString())
                if (groups.isEmpty()) {
                    sharedPreferences.edit().putStringSet("groups", groups).apply()
                    val intent = Intent(this, GroupActivity::class.java)
                    startActivity(intent)
                    finish()
                }
                sharedPreferences.edit().putString("currentGroup", groups.toList()[0]).apply()
                finish()
            }
        }

        setUpAdminRelatedButtons()
    }

    private fun setUpMembers() {
        val users = parseIntArray(net.getUsersInGroup(groupId).body!!.string())

        for (user in users) {
            val groupMemberView = GroupMemberView(this, this as Context, net.getUsernameById(user).body!!.string(), user)

            groupMemberView.setOnLongClickListener { view ->
                if (!amIAnAdminIn(groupId)) return@setOnLongClickListener false
                val popupMenu = PopupMenu(this, groupMemberView)
                popupMenu.inflate(R.menu.user_pop_menu)
                popupMenu.setOnMenuItemClickListener { item ->
                    when(item.itemId) {
                        R.id.kick -> {



                            setUpMembers()
                            false
                        }
                        R.id.transfer_ownership -> {
                            AlertDialog.Builder(this)
                                .setMessage(getString(R.string.transfer_ownership_confirmation))
                                .setPositiveButton(R.string.yes) { _, _, ->
                                    val response: Response = net.transfer_ownership(groupId, (view as GroupMemberView).userId)
                                    Toast.makeText(this, response.body!!.string(), Toast.LENGTH_SHORT).show()
                                    setUpAdminRelatedButtons()
                                }
                                .setNegativeButton(R.string.no) { _, _, -> }
                                .show()
                            true
                        }
                        else -> false
                    }
                }
                popupMenu.show()
                true
            }

            binding.groupsContent.addView(groupMemberView)
        }
    }

    fun amIAnAdminIn(groupId: Int): Boolean {
        val net = Net()

        net.token = sharedPreferences.getString("token", "")!!
        net.server = sharedPreferences.getString("server", "")!!
        net.language = sharedPreferences.getString("language", "en-US")!!

        val result = sharedPreferences.getInt("userId", 0) == net.getGroupAdminId(groupId).body!!.string().toInt()
        return result
    }

    fun setUpAdminRelatedButtons() {
        isAdmin = amIAnAdminIn(groupId)

        if (!isAdmin) {
            binding.renameButton.visibility = View.GONE
        }
    }
}